#!/bin/bash

export COMPONENT_HASH=8dcf9dd73fffc38e34bd6c29ef01bd517f734b34
PKG_VERSION=0.4.15+cdh6.0.0
FULL_VERSION=0.4.15-cdh6.0.0
BASE_VERSION=0.4.15
PKG_RELEASE=537114
CDH_CUSTOMER_PATCH=p0
CDH_PARCEL_CUSTOM_VERSION=0.4.15+cdh6.0.0-537114.xenial
